referrerpolicy=no-referrer-when-downgrade

MaybeConsideration

Trait MaybeConsideration 

pub trait MaybeConsideration<AccountId, Footprint>: Consideration<AccountId, Footprint> {
    // Required method
    fn is_none(&self) -> bool;
}
An extension of the Consideration trait that allows for the management of tickets that may represent no cost. While the MaybeConsideration still requires proper handling, it introduces the ability to determine if a ticket represents no cost and can be safely forgotten without any side effects.

Required Methods

fn is_none(&self) -> bool

Returns true if this Consideration represents a no-cost ticket and can be forgotten without any side effects.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl<A, F> MaybeConsideration<A, F> for ()

Available on crate feature experimental only.


fn is_none(&self) -> bool

Implementors



impl<A, F, R, D, Fp> MaybeConsideration<A, Fp> for FreezeConsideration<A, F, R, D, Fp>
where A: 'static + Eq, F: 'static + Mutate<A> + Mutate<A>, R: 'static + Get<<F as Inspect<A>>::Id>, D: 'static + Convert<Fp, <F as Inspect<A>>::Balance>, Fp: 'static,

Available on crate feature experimental only.


impl<A, F, R, D, Fp> MaybeConsideration<A, Fp> for HoldConsideration<A, F, R, D, Fp>
where A: 'static + Eq, F: 'static + Mutate<A> + Mutate<A>, R: 'static + Get<<F as Inspect<A>>::Reason>, D: 'static + Convert<Fp, <F as Inspect<A>>::Balance>, Fp: 'static,

Available on crate feature experimental only.